#!/usr/bin/python

from pBabel import MOLFile_ToSystem, XYZFiles_ToSystemGeometryTrajectory, \
                   SystemGeometryTrajectory, \
                   XYZFiles_FromSystemGeometryTrajectory
from pMolecule import QCModelMNDO, ADIISSCFConverger, DIISSCFConverger, \
                      ElectronicState
from pMoleculeScripts import ConjugatePeakRefinementOptimizePath

#-----------------------------------------
# Define the molecule and its energy model
#-----------------------------------------
converger=ADIISSCFConverger(densityTolerance=10e-13 )
system = MOLFile_ToSystem( "./input/butane.mol"  )
system.electronicState = ElectronicState(charge = 0, multiplicity = 1)
qc_model = QCModelMNDO("rm1", converger=converger)
system.DefineQCModel (qc_model)
system.Summary ()

#-----------------------------------------------------
# Generate initial trajectory (at least 2 structures!)
#-----------------------------------------------------
initial_path = (
"./input/butane-anti-opt.xyz",
"./input/butane-gauche-opt.xyz",
)

traj_path = "cpr_traj"   # directory to save the path structures to

XYZFiles_ToSystemGeometryTrajectory(initial_path, traj_path, system)
trajectory     = SystemGeometryTrajectory(traj_path, system, mode = "a+")

#----------------------------------------------------------------
# Run CPR on the *system* starting from the initial *trajectory*
#----------------------------------------------------------------
ConjugatePeakRefinementOptimizePath ( system, trajectory, \
                                      rmsGradientTolerance = 0.001, \
				      breakIfTauReached = False, \
                                      interpolationIncreasement = 0, \
				      finalUnrefinableRefinement = False)

#----------------------------------------
# Convert the final path to .xyz formate
#----------------------------------------
XYZFiles_FromSystemGeometryTrajectory ( traj_path, traj_path, system )
